#ifndef STRUCT_COPY_INFOMATION_H
#define STRUCT_COPY_INFOMATION_H

#include <sys/types.h>

typedef enum copy_mode_flag
{
	SAME,
	DIFFERENT,
} CMF;

typedef enum copy_file_type
{
	REGULAR,
	SYMBOLICLINK,
	DIRECTORY,
} CFT;

typedef struct copy_infomation
{
	char *from;
	char *to;
	char *tofs;
	enum copy_file_type from_type;
	enum copy_mode_flag copy_mode;
	_Bool write;
	_Bool skip;
	_Bool compare;
	_Bool file_test;
	off_t from_size;
	off_t to_size;
} CPInfo;

#endif
